@@ -12,6 +12,7 @@ use constant DEBUG => $ENV{MOJO_SHIPMENT_DEBUG};
 
 has api_key => sub { croak 'api_key is required' };
 has api_url => sub { Mojo::URL->new('https://wwwcie.ups.com/ups.app/xml/Track') };
+has carrier_description => sub { 'UPS' };
 
 has template => <<'TEMPLATE';
 % my ($self, $id) = @_;
@@ -124,7 +125,7 @@ sub request {
       my $dom = _handle_response($tx);
       $self->$cb(undef, $dom);
     },
-  )->tap(on => error => sub{ $self->$cb($_[1], undef) })->wait;
+  )->catch(sub{ $self->$cb(pop, undef) })->wait;
 }
 
 sub _handle_response {
